@@ -3,7 +3,7 @@ package Health::BladderDiary::GenTable;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-12-10'; # DATE
 our $DIST = 'Health-BladderDiary-GenTable'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,6 +28,9 @@ $SPEC{gen_bladder_diary_table_from_entries} = {
             schema => 'str*',
             cmdline_aliases => {y=>{}},
         },
+        date => {
+            schema => ['date*', 'x.perl.coerce_to' => 'DateTime'],
+        },
     },
 };
 sub gen_bladder_diary_table_from_entries {
@@ -304,7 +307,7 @@ Health::BladderDiary::GenTable - Create bladder diary table from entries
 
 =head1 VERSION
 
-This document describes version 0.005 of Health::BladderDiary::GenTable (from Perl distribution Health-BladderDiary-GenTable), released on 2020-12-10.
+This document describes version 0.006 of Health::BladderDiary::GenTable (from Perl distribution Health-BladderDiary-GenTable), released on 2020-12-10.
 
 =head1 SYNOPSIS
 
@@ -462,6 +465,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<date> => I<date>
+
 =item * B<entries>* => I<str>
 
 =item * B<yesterday_last_urination_entry> => I<str>
